@@ -1,5 +1,9 @@
 <?php
-
+ini_set('include_path', 
+	dirname(__FILE__) . '/class'
+	. PATH_SEPARATOR . ini_get('include_path')
+);
+require_once('IPFilter.class.php');
 class IPLock extends CMSModule {
 	function GetName() {
 		return 'IPLock';
@@ -9,13 +13,13 @@ class IPLock extends CMSModule {
 		return $this->Lang ( 'friendlyname' );
 	}
 	function GetVersion() {
-		return '0.3.5';
+		return '0.4';
 	}
 	function MinimumCMSVersion() {
 		return '1.6';
 	}
 	function GetAuthor() {
-		return 'Redwarp';
+		return 'Benoit Vermont';
 	}
 	function GetAuthorEmail() {
 		return 'redwarp@gmail.com';
@@ -33,6 +37,7 @@ class IPLock extends CMSModule {
 	}
 	
 	function GetAdminDescription() {
+		//return $this->Lang ( 'moddescription' );
 		return $this->Lang ( 'moddescription' );
 	}
 	
@@ -41,7 +46,7 @@ class IPLock extends CMSModule {
 	}
 	
 	function UninstallPreMessage() {
-		return $this->Lang ( 'preuninstall' );
+		return html_entity_decode($this->Lang ( 'preuninstall' ),ENT_NOQUOTES, 'UTF-8');
 	}
 	function UninstallPostMessage() {
 		return $this->Lang ( 'postuninstall' );
@@ -56,8 +61,21 @@ class IPLock extends CMSModule {
 		return true;
 	}
 	function DefaultLanguage(){
-		return 'fr_FR';
+		return 'en_US';
 	}
+	
+	function GetNotificationOutput( $priority = 2 ){
+		if ($this->GetPreference('notification') == 'display' && $this->GetPreference('new_banned_ip') == 'not_verified' && $this->CheckPermission('IPLock Admin')){
+			$ret = new stdClass;
+			$ret->priority = 3;
+			$ret->html = $this->lang('notification_message', $this->CreateLink($id, 'defaultadmin', $returnid, $this->lang('friendlyname'), array('active_tab' => 'denied_ip')));
+			return $ret;
+		}
+		else {
+			return '';
+		}
+	} 
+	
 	function _GetDbName(){
 		return cms_db_prefix().'module_iplock';
 	}
@@ -65,71 +83,42 @@ class IPLock extends CMSModule {
 		return $this->_GetDbName() . '_watch';
 	}
 	function _IPFilterInit(){
-		require_once('class/IPFilter.class.php');
 		IPFilter::init($this);
 	}
 	
-	function DoEvent($originator, $eventname, $params) {
-		// On verifie que l'event reçu est bien LoginPost, originaire du Coeur
-		if ($originator == 'Core' && $eventname == 'LoginPost') {
-			
-			$this->_IPFilterInit ();
-			$ip = $_SERVER ["REMOTE_ADDR"];
-			/* Pur paranoïa : on redirige également l'utilisateur sur logout
-			 * au cas ou il aurait fourni des mauvais identifiants. */
-			global $password, $oneuser;
-			if (($oneuser->id == '' || $password == "")) {			
-				IPFilter::watchIP($ip, $this->GetPreference('max_conn_min'));
-				redirect ( 'logout.php' );
-			} else {
-				IPFilter::watchIPFlush($ip);
-			}
-			
-			$IPLock_mode = $this->GetPreference ( 'IPLock_mode' );
-			
-			if ($IPLock_mode == 'allow') {
-				$allowedIP = !IPFilter::isDeniedIP ( $ip );
-			} else {
-				
-				// L'ip est elle dans la liste des IPs autorisées ?
-				$allowedIP = IPFilter::isAllowedIP ( $ip );
-				// Et surtout, n'est elle pas bannie ?
-				$allowedIP = $allowedIP && ! IPFilter::isDeniedIP ( $ip );
-			}			
-			// A ce stade là, l'utilisateur est considéré comme logué.
-			// Mais si son IP est incorrecte, on le redirige vers la page logout.php, ce qui le dégage.
-			if (! $allowedIP) {
-				$this->Audit ( 42, $this->GetName (), $this->Lang ( 'wrongip', $ip ) );
-				redirect ( 'logout.php' );
-			}
-		}
-	}
-	
+	//TODO
+	///This should be pulled out at a smarty templete
 	function _IPTable($id, array $ipArray, array $parameters = null){
 		global $id;
 		$rowcount = count($ipArray);
+		$thead = $this->lang('ip_comment');
 		$liste = <<<TBS
 <table class='pagetable'>
 	<thead>
 		<tr>
-			<th width='100%'>IP</th>
+			<th width='20%'>IP</th>
+			<th width='100%'>$thead</th>
+			<th></th>
 			<th></th>
 		</tr>
 	</thead>
 	<tbody>
 TBS;
 		if( $rowcount == 0 ){
-			$liste .= "<tr class='row1'><td>".$this->Lang('emptylist')."</td><td></td></tr>";
+			$liste .= "<tr class='row1'><td colspan='4'>".$this->Lang('emptylist')."</tr>";
 		}
 		else {
 			$i = 0;
 			foreach( $ipArray as $ip_id => $ip_value){
+				$ip_comment = htmlspecialchars(IPFilter::getIPComment($ip_id));
 				// Construction des paramètres à donner à chaque lien.
 				foreach ( $parameters as $paramName => $paramValue ) {
 					$params [$paramName] = $paramValue;
 				}
 				$params['ip_id'] = $ip_id;
-				$liste .= "<tr class='row".($i%2+1)."'><td>$ip_value</td>";
+				$liste .= "<tr class='row".($i%2+1)."'><td>$ip_value</td><td>$ip_comment</td><td>".
+				$this->CreateLink ( $id, 'edit_ip_comment', $returnid, '<img src="../modules/' . $this->GetName () . '/images/edit.gif" class="systemicon" alt="' . $this->Lang ( 'edit' ) . '" title="' . $this->Lang ( 'edit' ) . '" />', $params).
+				"</td>";
 				if ($ip_value == '127.0.0.1') {
 					$liste .= '<td></td>';
 				} else {
@@ -147,18 +136,26 @@ TBE;
 	
 	function _IPField($id, $action){
 		global $params;
-		$ipfield = $this->CreateFormStart($id, $action, $returnid).
+		//$ipfield = $this->CreateFormStart($id, $action, $returnid). // $returnid is undefined should be passing in
+		$ipfield = $this->CreateFormStart($id, $action).'<p>'.
 		$this->CreateInputText($id, 'field0','',5).'.'.
 		$this->CreateInputText($id, 'field1','',5).'.'.
 		$this->CreateInputText($id, 'field2','',5).'.'.
 		$this->CreateInputText($id, 'field3','',5).
 		$this->CreateInputSubmit($id, 'submit', $this->Lang('add')).
-		$this->CreateFormEnd();
+		'</p>'.$this->CreateFormEnd();
 		if(isset($params[$action.'_error'])){
 			$ipfield .= $this->ShowErrors($params[$action.'_error']);
 		}
+		if ($action == 'allow_ip'){
+			$ipfield .= $this->CreateFormStart($id, $action).'<p>'.
+			$this->lang('add_current_ip', $_SERVER['REMOTE_ADDR']).' '.
+			$this->CreateInputHidden($id,'ip',$_SERVER['REMOTE_ADDR']).
+			$this->CreateInputSubmit($id, 'submit', $this->lang('add')).
+			'</p>'.$this->CreateFormEnd();
+		}
 		return $ipfield;
 	}
 }
 
-?>
+?>
\ No newline at end of file
