@@ -6,7 +6,12 @@ if(! $this->CheckPermission('IPLock Admin')){
 	return;
 }
 
-$ip = $params['field0'].'.'.$params['field1'].'.'.$params['field2'].'.'.$params['field3'];
+if(isset($params['ip'])){
+	$ip = $params['ip'];
+}
+else {
+	$ip = $params['field0'].'.'.$params['field1'].'.'.$params['field2'].'.'.$params['field3'];
+}
 
 $this->_IPFilterInit();
 
