@@ -6,8 +6,8 @@ if(! $this->CheckPermission('IPLock Admin')){
 	return;
 }
 
-if(isset($params['iplock_mode'])){
-	$this->SetPreference('iplock_mode', $params['iplock_mode']);
+if(isset($params['operating_process'])){
+	$this->SetPreference('operating_process', $params['operating_process']);
 }
 if(isset($params['max_conn_min'])){
 	if( is_numeric( $params['max_conn_min'] ) ){
@@ -17,9 +17,15 @@ if(isset($params['max_conn_min'])){
 		}
 	}
 }
+if(isset($params['notification'])){
+	$this->SetPreference('notification', $params['notification']);
+}
 
-
-
+if(isset($params['banned_template'])){
+$this->SetTemplate ('banned_template', $params['banned_template'], 'IPLock');
+}
+ 
+ 
 $returnparams['active_tab'] = 'prefs';
 $this->Redirect($id, 'defaultadmin', $returnid, $returnparams);
 
