@@ -8,13 +8,14 @@ $dict->ExecuteSQLArray($sqlarray);
 $sqlarray = $dict->DropTableSQL( $this->_GetDbName().'_watch');
 $dict->ExecuteSQLArray($sqlarray);
 
-$db->DropSequence ($this->_GetDbName().'_seq');
-$db->DropSequence ($this->_GetDbName().'_watch_seq');
 //Remove permission
+/* @var $this IPLock */
 $this->RemovePermission('IPLock Admin');
 
-$this->RemovePreference('IPLock_mode');
-$this->RemovePreference('max_conn_lock');
+$this->RemovePreference('operating_process');
+$this->RemovePreference('max_conn_min');
+$this->RemovePreference('new_banned_ip');
+$this->RemovePreference('notification');
 
 $this->RemoveEventHandler('Core', 'LoginPost');
 
